@@ -78,6 +78,7 @@ class UserProfile:
     user_types: List[str] = field(default_factory=list)
     user_specific_features: List[str] = field(default_factory=list)
     features: List[str] = field(default_factory=list)
+    created_at: Optional[datetime] = None
 
     @classmethod
     def from_dict(cls, _dict) -> "UserProfile":
@@ -100,6 +101,9 @@ class UserProfile:
             user_types=_dict.get("user_types") or [],
             user_specific_features=_dict.get("user_specific_features") or [],
             features=_dict.get("features") or [],
+            created_at=datetime.fromisoformat(_dict["created_at"])
+            if _dict.get("created_at")
+            else None,
         )
 
     def to_dict(self):
