@@ -1,4 +1,5 @@
 import json
+from typing import Dict
 from uuid import uuid4, UUID
 from http import HTTPStatus
 
@@ -161,6 +162,23 @@ def test_update_profile_on_adding_user_types_and_user_specific_features():
     )
 
 
+@responses.activate
+def test_update_profile_returns_429():
+    user_id = UUID(incomplete_user_profile_dict["id"])
+
+    responses.add(
+        responses.PATCH,
+        f"http://dummy_profile/api/v1/new/profiles/{user_id}",
+        content_type="application/json",
+        status=429,
+    )
+
+    with pytest.raises(TooManyRequests):
+        user_service.update_profile(
+            user_id=user_id, profile={"push_notification_id": "fcm-is-gcm-is-fcm"}
+        )
+
+
 @responses.activate
 def test_update_profile_on_removing_user_types_and_user_specific_features():
     user_profile = UserProfile.from_dict(user_profile_dict)
@@ -253,6 +271,93 @@ def test_get_user_from_active_session_throws_rte_if_non_ok_response():
     assert "value" in str(exc_info.value)
 
 
+@responses.activate
+def test_get_user_profiles_count_by_device_id():
+    device_id, count = str(uuid4()), 10
+    responses.add(
+        responses.GET,
+        f"http://dummy_profile/api/v1/profile_count/by_device_id",
+        status=200,
+        json={"data": dict(profile_count=count)},
+    )
+    profile_count = user_service.get_user_profiles_count_by_device_id(device_id)
+    assert profile_count == count
+
+
+@responses.activate
+def test_get_user_profiles_count_by_device_id_if_non_ok_response():
+    device_id = str(uuid4())
+    responses.add(
+        responses.GET,
+        f"http://dummy_profile/api/v1/profile_count/by_device_id",
+        status=500,
+    )
+    with pytest.raises(RuntimeError) as exc_info:
+        user_service.get_user_profiles_count_by_device_id(device_id)
+
+    assert "500" in str(exc_info.value)
+
+
+@responses.activate
+def test_get_devices():
+    user_id, device_id = str(uuid4()), str(uuid4())
+    responses.add(
+        responses.GET,
+        f"http://dummy_profile/api/v1/devices/by_user_id",
+        status=200,
+        json={"data": [user_device_dict(user_id, device_id)]},
+    )
+    user_devices = user_service.get_devices(user_id)
+    assert [user_device.user_id for user_device in user_devices] == [user_id]
+    assert [user_device.device_id for user_device in user_devices] == [device_id]
+
+
+@responses.activate
+def test_get_devices_if_non_ok_response():
+    user_id = str(uuid4())
+    responses.add(
+        responses.GET,
+        f"http://dummy_profile/api/v1/devices/by_user_id",
+        status=500,
+        json=dict(key="value"),
+    )
+    with pytest.raises(RuntimeError) as exc_info:
+        user_service.get_devices(user_id)
+
+    assert "500" in str(exc_info.value)
+
+
+@responses.activate
+def test_get_profile_by_email():
+    email = "test@shuttl.com"
+    responses.add(
+        responses.GET,
+        f"http://dummy_profile/api/v1/profiles/by_email",
+        status=200,
+        json={"data": user_profile_dict},
+    )
+    user_profile = user_service.get_profile_by_email(email=email)
+    assert user_profile.name == "sample_name"
+    assert "sample_work_address" == user_profile.work_address.location_name
+    assert "sample_home_address" == user_profile.home_address.location_name
+    assert "MALE" == user_profile.gender.name
+
+
+@responses.activate
+def test_get_get_profile_by_email_if_non_ok_response():
+    email = "test@shuttl.com"
+    responses.add(
+        responses.GET,
+        f"http://dummy_profile/api/v1/profiles/by_email",
+        status=500,
+        json=dict(key="value"),
+    )
+    with pytest.raises(RuntimeError) as exc_info:
+        user_service.get_profile_by_email(email=email)
+
+    assert "500" in str(exc_info.value)
+
+
 user_dict = {
     "created_at": "2018-10-18T09:05:59.334113",
     "credentials": [
@@ -270,6 +375,7 @@ user_dict = {
     "updated_at": "2018-10-18T09:05:59.334119",
 }
 
+
 user_profile_dict = {
     "created_at": "2018-10-18T13:04:55.643673",
     "gender": "MALE",
@@ -342,6 +448,15 @@ session_response = {
 }
 
 
+def user_device_dict(user_id, device_id) -> Dict:
+    return {
+        "user_id": user_id,
+        "device_id": device_id,
+        "app_version": "V.3.1",
+        "platform": "Android",
+    }
+
+
 @responses.activate
 def test_login_raises_too_many_requests_error_if_status_code_received_from_user_auth_service_is_429():
     responses.add(
