@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import List, Optional
+from typing import List, Optional, Dict
 from uuid import UUID
 
 import requests
@@ -223,6 +223,8 @@ class UserService:
             raise ProfileUpdateError(response.json().get("error"))
         if response.status_code == HTTPStatus.NOT_FOUND:
             raise NoSuchProfile
+        if response.status_code == HTTPStatus.TOO_MANY_REQUESTS:
+            raise TooManyRequests
 
         self._raise_response_error(response)
 
@@ -242,6 +244,22 @@ class UserService:
 
         self._raise_response_error(response)
 
+    def get_profile_by_email(self, email: str) -> UserProfile:
+        request_url = f"{self._profile_url}/api/v1/profiles/by_email"
+        response = requests.get(url=request_url, params={"email": email})
+        log(
+            message="get_user_profile",
+            request_url=request_url,
+            status_code=response.status_code,
+            response=response.text,
+        )
+        if response.status_code == HTTPStatus.OK:
+            return UserProfile.from_dict(response.json().get("data"))
+        if response.status_code == HTTPStatus.NOT_FOUND:
+            raise NoSuchProfile
+
+        self._raise_response_error(response)
+
     def get_user_profiles(self, ids: List[UUID]) -> List[UserProfile]:
         request_url = f"{self._profile_url}/api/v1/profiles/by_user_ids"
         response = requests.get(request_url, params={"ids": ",".join(map(str, ids))})
@@ -256,6 +274,29 @@ class UserService:
 
         self._raise_response_error(response)
 
+    def get_user_profiles_count_by_device_id(self, device_id: str) -> int:
+        request_url = f"{self._profile_url}/api/v1/profile_count/by_device_id"
+        response = requests.get(request_url, params={"id": device_id})
+        log(
+            message="get_user_profile",
+            request_url=request_url,
+            status_code=response.status_code,
+            response=response.text,
+        )
+        if response.status_code == HTTPStatus.OK:
+            return response.json()["data"]["profile_count"]
+
+        self._raise_response_error(response)
+
+    def get_devices(self, user_id: str) -> List[UserDevice]:
+        request_url = f"{self._profile_url}/api/v1/devices/by_user_id"
+        response = requests.get(request_url, params={"id": user_id})
+        if response.status_code == HTTPStatus.OK:
+            return [
+                UserDevice.from_dict(data_dict) for data_dict in response.json()["data"]
+            ]
+        self._raise_response_error(response)
+
     def create_user(self, user_request: UserRequest):
         request_url = f"{self._authentication_url}/api/v1/users"
 
